timespantools.OffsetTimespanTimeRelation
========================================

.. abjad-lineage:: abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation

.. autoclass:: abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.inequality
      ~abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.is_fully_loaded
      ~abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.is_fully_unloaded
      ~abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.offset
      ~abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.timespan
      ~abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.__call__
      ~abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.__eq__
      ~abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.__format__
      ~abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.__makenew__
      ~abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.__ne__
      ~abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.__repr__

Bases
-----

- :py:class:`timespantools.TimeRelation <abjad.tools.timespantools.TimeRelation.TimeRelation>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.inequality
   :noindex:

.. autoattribute:: abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.is_fully_loaded
   :noindex:

.. autoattribute:: abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.is_fully_unloaded
   :noindex:

.. autoattribute:: abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.offset
   :noindex:

.. autoattribute:: abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.timespan
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.__call__
   :noindex:

.. automethod:: abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.__eq__
   :noindex:

.. automethod:: abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.__format__
   :noindex:

.. automethod:: abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.__makenew__
   :noindex:

.. automethod:: abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.__ne__
   :noindex:

.. automethod:: abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation.__repr__
   :noindex:
